@@ -4,6 +4,15 @@ from pinout.components import leaderline as lline
 from pinout import config
 
 
+def pitch_generator(start, pitch):
+    x = start[0]
+    y = start[1]
+    while True:
+        yield (x, y)
+        x += pitch[0]
+        y += pitch[1]
+
+
 class Body(SvgShape):
     """Graphical shape that makes up the body of a pinlabel."""
 
@@ -57,8 +66,15 @@ class Base(Group):
         super().__init__(x, y, tag=tag, **kwargs)
         self.update_config(config.pinlabel)
 
-        self.leaderline = leaderline
         self.body = body
+        self.leaderline = leaderline
+
+        # Add leaderline and body reference into children
+        self.add(self._body)
+
+        # Add leaderline at render as it is replaced by pinlabelGroup!!!
+        # Add SvgShape so pin label reports correct dimensions.
+        self.add(SvgShape(x=self.leaderline.x, y=self.leaderline.x))
 
         self.add_tag(config.pinlabel["tag"])
 
@@ -96,19 +112,7 @@ class Base(Group):
         leaderline.add_tag(self.config["leaderline"]["tag"])
         self._leaderline = leaderline
 
-    def bounding_coords(self):
-        return BoundingCoords(
-            self.x,
-            self.y,
-            self.x + self.body.bounding_coords().x2,
-            self.y + self.body.bounding_coords().y2,
-        )
-
     def render(self):
-
-        self.add(self.leaderline)
-        self.add(self.body)
-
         # Add text content
         x = self.body.width / 2 + self.body.x
         y = self.body.y
@@ -122,7 +126,8 @@ class Base(Group):
             )
         )
         # Route leaderline
-        self.leaderline.route(Rect(), self.body)
+        self.leaderline.route(Rect(), self._body)
+        self.add(self.leaderline)
         return super().render()
 
 
@@ -149,8 +154,8 @@ class PinLabelGroup(Group):
         super().__init__(x=x, y=y, **kwargs)
 
         # Setup generators for row locations
-        pin_coords = config.pitch_generator((0, 0), pin_pitch)
-        label_coords = config.pitch_generator(label_start, label_pitch)
+        pin_coords = pitch_generator((0, 0), pin_pitch)
+        label_coords = pitch_generator(label_start, label_pitch)
 
         for row in labels:
             row_group = self.add(Group())
@@ -182,7 +187,6 @@ class PinLabelGroup(Group):
                     label.x = prev_label.x + prev_label.width * scale.x
                     label.y = prev_label.y + prev_label.body.y * scale.y
                     label.leaderline = lline.Straight(direction="hh")
-
                 # Start of a new row
                 except IndexError:
                     label.x, label.y = next(pin_coords)
